# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import stt_service_pb2 as stt__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in stt_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SttServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamingRecognize = channel.stream_stream(
                '/ari.stt.v1.SttService/StreamingRecognize',
                request_serializer=stt__service__pb2.StreamingRecognitionRequest.SerializeToString,
                response_deserializer=stt__service__pb2.StreamingRecognitionResponse.FromString,
                _registered_method=True)
        self.Models = channel.unary_unary(
                '/ari.stt.v1.SttService/Models',
                request_serializer=stt__service__pb2.ModelsRequest.SerializeToString,
                response_deserializer=stt__service__pb2.ModelsResponse.FromString,
                _registered_method=True)
        self.NLPFunctions = channel.unary_unary(
                '/ari.stt.v1.SttService/NLPFunctions',
                request_serializer=stt__service__pb2.NLPFunctionsRequest.SerializeToString,
                response_deserializer=stt__service__pb2.NLPFunctionsResponse.FromString,
                _registered_method=True)
        self.AccountInfo = channel.unary_unary(
                '/ari.stt.v1.SttService/AccountInfo',
                request_serializer=stt__service__pb2.AccountInfoRequest.SerializeToString,
                response_deserializer=stt__service__pb2.AccountInfoResponse.FromString,
                _registered_method=True)
        self.NLPProcess = channel.unary_unary(
                '/ari.stt.v1.SttService/NLPProcess',
                request_serializer=stt__service__pb2.NLPProcessRequest.SerializeToString,
                response_deserializer=stt__service__pb2.NLPProcessResponse.FromString,
                _registered_method=True)


class SttServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StreamingRecognize(self, request_iterator, context):
        """Transcribe a stream of audio.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Models(self, request, context):
        """List all supported models.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NLPFunctions(self, request, context):
        """List all available nlp server configs and corresponding functions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NLPProcess(self, request, context):
        """Processes the given text with the given nlp pipeline.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SttServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamingRecognize': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamingRecognize,
                    request_deserializer=stt__service__pb2.StreamingRecognitionRequest.FromString,
                    response_serializer=stt__service__pb2.StreamingRecognitionResponse.SerializeToString,
            ),
            'Models': grpc.unary_unary_rpc_method_handler(
                    servicer.Models,
                    request_deserializer=stt__service__pb2.ModelsRequest.FromString,
                    response_serializer=stt__service__pb2.ModelsResponse.SerializeToString,
            ),
            'NLPFunctions': grpc.unary_unary_rpc_method_handler(
                    servicer.NLPFunctions,
                    request_deserializer=stt__service__pb2.NLPFunctionsRequest.FromString,
                    response_serializer=stt__service__pb2.NLPFunctionsResponse.SerializeToString,
            ),
            'AccountInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountInfo,
                    request_deserializer=stt__service__pb2.AccountInfoRequest.FromString,
                    response_serializer=stt__service__pb2.AccountInfoResponse.SerializeToString,
            ),
            'NLPProcess': grpc.unary_unary_rpc_method_handler(
                    servicer.NLPProcess,
                    request_deserializer=stt__service__pb2.NLPProcessRequest.FromString,
                    response_serializer=stt__service__pb2.NLPProcessResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ari.stt.v1.SttService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ari.stt.v1.SttService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SttService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StreamingRecognize(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/ari.stt.v1.SttService/StreamingRecognize',
            stt__service__pb2.StreamingRecognitionRequest.SerializeToString,
            stt__service__pb2.StreamingRecognitionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Models(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ari.stt.v1.SttService/Models',
            stt__service__pb2.ModelsRequest.SerializeToString,
            stt__service__pb2.ModelsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def NLPFunctions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ari.stt.v1.SttService/NLPFunctions',
            stt__service__pb2.NLPFunctionsRequest.SerializeToString,
            stt__service__pb2.NLPFunctionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AccountInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ari.stt.v1.SttService/AccountInfo',
            stt__service__pb2.AccountInfoRequest.SerializeToString,
            stt__service__pb2.AccountInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def NLPProcess(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ari.stt.v1.SttService/NLPProcess',
            stt__service__pb2.NLPProcessRequest.SerializeToString,
            stt__service__pb2.NLPProcessResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
